@@ -20,6 +20,8 @@ from Screens.InfoBarGenerics import streamrelay
 
 
 class Navigation:
+	playServiceExtensions = []
+	recordServiceExtensions = []
 	def __init__(self):
 		if NavigationInstance.instance is not None:
 			raise NavigationInstance.instance
@@ -38,6 +40,7 @@ class Navigation:
 		self.currentlyPlayingServiceReference = None
 		self.currentlyPlayingServiceOrGroup = None
 		self.currentlyPlayingService = None
+		self.originalPlayingServiceReference = None
 		self.currentServiceIsStreamRelay = False
 		self.skipServiceReferenceReset = False
 		self.RecordTimer = RecordTimer.RecordTimer()
@@ -51,7 +54,7 @@ class Navigation:
 			ImportChannels()
 		if self.__wasTimerWakeup:
 			self.wakeup_timer_enabled = wakeup_time_type == 3 and self.__prevWakeupTime
-			if not self.wakeup_timer_enabled:
+			if self.__prevWakeupTime and wakeup_time_type in (0, 1) and not config.misc.RestartUI.value:
 				RecordTimer.RecordTimerEntry.setWasInDeepStandby()
 		if config.misc.RestartUI.value:
 			config.misc.RestartUI.value = False
@@ -60,7 +63,7 @@ class Navigation:
 		else:
 			if config.usage.remote_fallback_import.value and not config.usage.remote_fallback_import_restart.value:
 				ImportChannels()
-			if startup_to_standby == "yes" or (self.__wasTimerWakeup and self.__prevWakeupTime and (wakeup_time_type == 0 or wakeup_time_type == 1 or (wakeup_time_type == 3 and startup_to_standby == "except"))):
+			if startup_to_standby == "yes" or (self.__wasTimerWakeup and self.__prevWakeupTime and (wakeup_time_type in (0, 1) or (wakeup_time_type == 3 and startup_to_standby == "except"))):
 				if not Screens.Standby.inTryQuitMainloop:
 					self.standbytimer = eTimer()
 					self.standbytimer.callback.append(self.gotostandby)
@@ -100,7 +103,14 @@ class Navigation:
 	def restartService(self):
 		self.playService(self.currentlyPlayingServiceOrGroup, forceRestart=True)
 
-	def playService(self, ref, checkParentalControl=True, forceRestart=False, adjust=True):
+	def playService(self, ref, checkParentalControl=True, forceRestart=False, adjust=True, event=None):
+		# Some plugins send None as ref becasue want to shutdown enigma play system.
+		# So we have to stop current service if someone send None.
+		if ref is None:
+			self.stopService()
+			return 0
+		
+		InfoBarInstance = InfoBar.instance
 		session = None
 		startPlayingServiceOrGroup = None
 		count = isinstance(adjust, list) and len(adjust) or 0
@@ -110,16 +120,34 @@ class Navigation:
 				startPlayingServiceOrGroup = adjust[2]
 			adjust = adjust[0]
 		oldref = self.currentlyPlayingServiceOrGroup
+		current_service_source = None
+		is_handled = False
+		if InfoBarInstance:
+			current_service_source = InfoBarInstance.session.screen["CurrentService"]
+
+		if "%3a//" in ref.toString():
+			self.currentlyPlayingServiceReference = None
+			self.currentlyPlayingService = None
+			if current_service_source:
+				current_service_source.newService(False)
+
 		if ref and oldref and ref == oldref and not forceRestart:
 			print("[Navigation] ignore request to play already running service(1)")
 			return 1
-		print("[Navigation] playing: ", ref and ref.toString())
-		if ref is None:
-			self.stopService()
-			return 0
-		from Components.ServiceEventTracker import InfoBarCount
-		InfoBarInstance = InfoBarCount == 1 and InfoBar.instance
+		print("[Navigation] playing ref", ref and ref.toString())
+
 		if not checkParentalControl or parentalControl.isServicePlayable(ref, boundFunction(self.playService, checkParentalControl=False, forceRestart=forceRestart, adjust=(count > 1 and [0, session] or adjust)), session=session):
+
+			self.currentlyPlayingServiceReference = ref
+			self.currentlyPlayingServiceOrGroup = ref
+			self.originalPlayingServiceReference = ref
+
+			if InfoBarInstance and current_service_source:
+				current_service_source.newService(ref)
+				InfoBarInstance.session.screen["Event_Now"].updateSource(self.currentlyPlayingServiceReference)
+				InfoBarInstance.session.screen["Event_Next"].updateSource(self.currentlyPlayingServiceReference)
+				InfoBarInstance.serviceStarted()
+
 			if ref.flags & eServiceReference.isGroup:
 				oldref = self.currentlyPlayingServiceReference or eServiceReference()
 				playref = getBestPlayableServiceReference(ref, oldref)
@@ -160,8 +188,16 @@ class Navigation:
 					self.pnav.stopService()
 				else:
 					self.skipServiceReferenceReset = True
+
 				self.currentlyPlayingServiceReference = playref
-				playref = streamrelay.streamrelayChecker(playref)
+				playref, is_stream_relay = streamrelay.streamrelayChecker(playref)
+
+				if BoxInfo.getItem("FCCactive") and "%3a//" in ref.toString() and not is_stream_relay:
+					self.pnav.stopService()
+
+				for f in Navigation.playServiceExtensions:
+					playref, is_handled = f(self, playref, event, InfoBarInstance)
+
 				self.currentlyPlayingServiceOrGroup = ref
 				if startPlayingServiceOrGroup and startPlayingServiceOrGroup.flags & eServiceReference.isGroup and not ref.flags & eServiceReference.isGroup:
 					self.currentlyPlayingServiceOrGroup = startPlayingServiceOrGroup
@@ -203,20 +239,23 @@ class Navigation:
 					self.retryServicePlayTimer = eTimer()
 					self.retryServicePlayTimer.callback.append(boundFunction(self.playService, ref, checkParentalControl, forceRestart, adjust))
 					self.retryServicePlayTimer.start(config.misc.softcam_streamrelay_delay.value, True)
-				elif self.pnav.playService(playref):
-					# print("[Navigation] Failed to start", playref)
-					self.currentlyPlayingServiceReference = None
-					self.currentlyPlayingServiceOrGroup = None
-					if oldref and "://" in oldref.getPath():
-						print("[Navigation] Streaming was active -> try again") # use timer to give the streamserver the time to deallocate the tuner
-						self.retryServicePlayTimer = eTimer()
-						self.retryServicePlayTimer.callback.append(boundFunction(self.playService, ref, checkParentalControl, forceRestart, adjust))
-						self.retryServicePlayTimer.start(500, True)
+				elif not is_handled and self.pnav.playService(playref):
+						self.currentlyPlayingServiceReference = None
+						self.originalPlayingServiceReference = None
+						self.currentlyPlayingServiceOrGroup = None
+						if oldref and "://" in oldref.getPath():
+							print("[Navigation] Streaming was active -> try again")  # use timer to give the streamserver the time to deallocate the tuner
+							self.retryServicePlayTimer = eTimer()
+							self.retryServicePlayTimer.callback.append(boundFunction(self.playService, ref, checkParentalControl, forceRestart, adjust))
+							self.retryServicePlayTimer.start(500, True)
 				self.skipServiceReferenceReset = False
 				if setPriorityFrontend:
 					setPreferredTuner(int(config.usage.frontend_priority.value))
 				if self.currentlyPlayingServiceReference and self.currentlyPlayingServiceReference.toString() in streamrelay.data:
 					self.currentServiceIsStreamRelay = True
+				if InfoBarInstance and "%3a//" in playref.toString() and not is_handled:
+					self.originalPlayingServiceReference = None
+					InfoBarInstance.serviceStarted()
 				return 0
 		elif oldref and InfoBarInstance and InfoBarInstance.servicelist.servicelist.setCurrent(oldref, adjust):
 			self.currentlyPlayingServiceOrGroup = InfoBarInstance.servicelist.servicelist.getCurrent()
@@ -228,6 +267,9 @@ class Navigation:
 	def getCurrentlyPlayingServiceOrGroup(self):
 		return self.currentlyPlayingServiceOrGroup
 
+	def getCurrentServiceReferenceOriginal(self):
+		return self.originalPlayingServiceReference or self.currentlyPlayingServiceOrGroup
+
 	def recordService(self, ref, simulate=False):
 		service = None
 		if isinstance(ref, ServiceReference):
@@ -237,7 +279,9 @@ class Navigation:
 		if ref:
 			if ref.flags & eServiceReference.isGroup:
 				ref = getBestPlayableServiceReference(ref, eServiceReference(), simulate)
-			ref = streamrelay.streamrelayChecker(ref)
+			ref = streamrelay.streamrelayChecker(ref)[0]
+			for f in Navigation.recordServiceExtensions:
+				ref = f(self, ref)
 			service = ref and self.pnav and self.pnav.recordService(ref, simulate)
 			if service is None:
 				print("[Navigation] record returned non-zero")
