@@ -1,15 +1,15 @@
 from __future__ import absolute_import, print_function
 
-import os
 import time
-
+from os.path import exists
+from os import remove
 import Components.PluginComponent
-import enigma
 import Screens.Standby
 import NavigationInstance
+from enigma import eServiceCenter, eServiceReference, eEPGCache, getDesktop, eTimer, eConsoleAppContainer
 from Components.ActionMap import ActionMap
 from Components.Button import Button
-from Components.config import config, getConfigListEntry, ConfigClock, ConfigEnableDisable, ConfigNumber, ConfigSelection, ConfigSubDict, ConfigSubsection, ConfigText, ConfigYesNo, NoSave
+from Components.config import config, getConfigListEntry, ConfigClock, ConfigEnableDisable, ConfigNumber, ConfigInteger, ConfigSelection, ConfigSubDict, ConfigSubsection, ConfigText, ConfigYesNo, NoSave
 from Components.ConfigList import ConfigListScreen
 from Components.Console import Console
 from Components.Label import Label
@@ -44,28 +44,29 @@ def calcDefaultStarttime():
 	return (5 * 60 * 60) + offset
 
 
-#Set default configuration
+# Set default configuration
 config.plugins.epgimport = ConfigSubsection()
 config.plugins.epgimport.enabled = ConfigEnableDisable(default=True)
+config.plugins.epgimport.repeat_import = ConfigInteger(default=0, limits=(0, 23))
 config.plugins.epgimport.runboot = ConfigSelection(default="4", choices=[
-		("1", _("always")),
-		("2", _("only manual boot")),
-		("3", _("only automatic boot")),
-		("4", _("never"))
-		])
+	("1", _("always")),
+	("2", _("only manual boot")),
+	("3", _("only automatic boot")),
+	("4", _("never"))
+])
 config.plugins.epgimport.runboot_restart = ConfigYesNo(default=False)
 config.plugins.epgimport.runboot_day = ConfigYesNo(default=False)
 config.plugins.epgimport.wakeup = ConfigClock(default=calcDefaultStarttime())
 config.plugins.epgimport.showinextensions = ConfigYesNo(default=True)
 config.plugins.epgimport.deepstandby = ConfigSelection(default="skip", choices=[
-		("wakeup", _("wake up and import")),
-		("skip", _("skip the import"))
-		])
+	("wakeup", _("wake up and import")),
+	("skip", _("skip the import"))
+])
 config.plugins.epgimport.loadepg_only = ConfigSelection(default="default", choices=[
-		("default", _("checking service reference(default)")),
-		("iptv", _("only IPTV channels")),
-		("all", _("all channels"))
-		])
+	("default", _("checking service reference(default)")),
+	("iptv", _("only IPTV channels")),
+	("all", _("all channels"))
+])
 config.plugins.epgimport.execute_shell = ConfigYesNo(default=False)
 config.plugins.epgimport.shell_name = ConfigText(default="")
 config.plugins.epgimport.standby_afterwakeup = ConfigYesNo(default=False)
@@ -93,11 +94,11 @@ weekdays = [
 	_("Friday"),
 	_("Saturday"),
 	_("Sunday"),
-	]
+]
 
 # historically located (not a problem, we want to update it)
 CONFIG_PATH = '/etc/epgimport'
-
+STANDBY_FLAG_FILE = "/tmp/enigmastandby"
 # Global variable
 autoStartTimer = None
 _session = None
@@ -110,7 +111,7 @@ isFilterRunning = 0
 def getAlternatives(service):
 	if not service:
 		return None
-	alternativeServices = enigma.eServiceCenter.getInstance().list(service)
+	alternativeServices = eServiceCenter.getInstance().list(service)
 	return alternativeServices and alternativeServices.getContent("S", True)
 
 
@@ -126,19 +127,19 @@ def getBouquetChannelList():
 	channels = []
 	global isFilterRunning, filterCounter
 	isFilterRunning = 1
-	serviceHandler = enigma.eServiceCenter.getInstance()
-	mask = (enigma.eServiceReference.isMarker | enigma.eServiceReference.isDirectory)
-	altrernative = enigma.eServiceReference.isGroup
+	serviceHandler = eServiceCenter.getInstance()
+	mask = (eServiceReference.isMarker | eServiceReference.isDirectory)
+	altrernative = eServiceReference.isGroup
 	if config.usage.multibouquet.value:
 		bouquet_rootstr = '1:7:1:0:0:0:0:0:0:0:FROM BOUQUET "bouquets.tv" ORDER BY bouquet'
-		bouquet_root = enigma.eServiceReference(bouquet_rootstr)
+		bouquet_root = eServiceReference(bouquet_rootstr)
 		list = serviceHandler.list(bouquet_root)
 		if list:
 			while True:
 				s = list.getNext()
 				if not s.valid():
 					break
-				if s.flags & enigma.eServiceReference.isDirectory:
+				if s.flags & eServiceReference.isDirectory:
 					info = serviceHandler.info(s)
 					if info:
 						clist = serviceHandler.list(s)
@@ -162,9 +163,9 @@ def getBouquetChannelList():
 											channels.append(refnum)
 	else:
 		bouquet_rootstr = '1:7:1:0:0:0:0:0:0:0:FROM BOUQUET "userbouquet.favourites.tv" ORDER BY bouquet'
-		bouquet_root = enigma.eServiceReference(bouquet_rootstr)
+		bouquet_root = eServiceReference(bouquet_rootstr)
 		services = serviceHandler.list(bouquet_root)
-		if not services is None:
+		if services is not None:
 			while True:
 				service = services.getNext()
 				filterCounter += 1
@@ -197,7 +198,7 @@ def channelFilter(ref):
 			return True
 		elif loadepg_only == "iptv":
 			return ("%3a//" not in ref.lower() or ref.startswith("1")) and False or True
-	sref = enigma.eServiceReference(ref)
+	sref = eServiceReference(ref)
 	refnum = getRefNum(sref.toString())
 	if config.plugins.epgimport.import_onlybouquet.value:
 		global BouquetChannelListList
@@ -226,7 +227,7 @@ def channelFilter(ref):
 	return False
 
 
-epgimport = EPGImport.EPGImport(enigma.eEPGCache.getInstance(), channelFilter)
+epgimport = EPGImport.EPGImport(eEPGCache.getInstance(), channelFilter)
 
 lastImportResult = None
 
@@ -252,7 +253,7 @@ def startImport():
 # Configuration GUI
 HD = False
 try:
-	if enigma.getDesktop(0).size().width() >= 1280:
+	if getDesktop(0).size().width() >= 1280:
 		HD = True
 except:
 	pass
@@ -332,7 +333,7 @@ class EPGImportConfig(ConfigListScreen, Screen):
 		self.createSetup()
 		self.filterStatusTemplate = _("Filtering: %s\nPlease wait!")
 		self.importStatusTemplate = _("Importing: %s\n%s events")
-		self.updateTimer = enigma.eTimer()
+		self.updateTimer = eTimer()
 		self.updateTimer.callback.append(self.updateStatus)
 		self.updateTimer.start(2000)
 		self.updateStatus()
@@ -361,6 +362,7 @@ class EPGImportConfig(ConfigListScreen, Screen):
 		self.cfg_execute_shell = getConfigListEntry(_("Execute shell command before import EPG"), self.EPG.execute_shell, _("When enabled, then you can run the desired script before starting the import, after which the import of the EPG will begin."))
 		self.cfg_shell_name = getConfigListEntry(dx + _("Shell command name"), self.EPG.shell_name, _("Enter shell command name."))
 		self.cfg_run_after_standby = getConfigListEntry(_("Start import after standby"), self.EPG.run_after_standby, _("Start import after resuming from standby mode."))
+		self.cfg_repeat_import = getConfigListEntry(dx + _("Hours after which the import is repeated"), self.EPG.repeat_import, _("Number of hours (1-23, or 0 for no repeat) after which the import is repeated. This value is not saved and will be reset when the GUI restarts."))
 
 	def createSetup(self):
 		self.list = [self.cfg_enabled]
@@ -371,6 +373,9 @@ class EPGImportConfig(ConfigListScreen, Screen):
 				self.list.append(self.cfg_shutdown)
 				if not self.EPG.shutdown.value:
 					self.list.append(self.cfg_standby_afterwakeup)
+					self.list.append(self.cfg_repeat_import)
+			else:
+				self.list.append(self.cfg_repeat_import)
 		self.list.append(self.cfg_day_profile)
 		self.list.append(self.cfg_runboot)
 		if self.EPG.runboot.value != "4":
@@ -380,7 +385,7 @@ class EPGImportConfig(ConfigListScreen, Screen):
 		self.list.append(self.cfg_loadepg_only)
 		if self.EPG.loadepg_only.value == "default":
 			self.list.append(self.cfg_import_onlybouquet)
-		if hasattr(enigma.eEPGCache, 'flushEPG'):
+		if hasattr(eEPGCache, 'flushEPG'):
 			self.list.append(self.cfg_clear_oldepg)
 		self.list.append(self.cfg_filter_custom_channel)
 		self.list.append(self.cfg_longDescDays)
@@ -389,7 +394,7 @@ class EPGImportConfig(ConfigListScreen, Screen):
 			self.list.append(self.cfg_shell_name)
 		if fileExists(resolveFilename(SCOPE_PLUGINS, "Extensions/AutoTimer/plugin.pyo")) or fileExists(resolveFilename(SCOPE_PLUGINS, "Extensions/AutoTimer/plugin.pyc")):
 			try:
-				from Plugins.Extensions.AutoTimer.AutoTimer import AutoTimer
+				# from Plugins.Extensions.AutoTimer.AutoTimer import AutoTimer
 				self.list.append(self.cfg_parse_autotimer)
 			except:
 				print("[EPGImport] AutoTimer plugin not installed correctly", file=log)
@@ -407,11 +412,29 @@ class EPGImportConfig(ConfigListScreen, Screen):
 		self.updateTimer.stop()
 		if self.EPG.parse_autotimer.value and (not fileExists(resolveFilename(SCOPE_PLUGINS, "Extensions/AutoTimer/plugin.pyo")) or not fileExists(resolveFilename(SCOPE_PLUGINS, "Extensions/AutoTimer/plugin.pyc"))):
 			self.EPG.parse_autotimer.value = False
+		if self.EPG.deepstandby.value == "skip" and self.EPG.shutdown.value:
+			self.EPG.shutdown.value = False
 		if self.EPG.shutdown.value:
 			self.EPG.standby_afterwakeup.value = False
-		self.EPG.save()
+			self.EPG.repeat_import.value = 0
+		# self.EPG.save()
 		if self.prev_onlybouquet != config.plugins.epgimport.import_onlybouquet.value or (autoStartTimer is not None and autoStartTimer.prev_multibouquet != config.usage.multibouquet.value):
 			EPGConfig.channelCache = {}
+		self.save()
+
+	def save(self):
+		if self["config"].isChanged():
+			for x in self["config"].list:
+				x[1].save()
+			self.EPG.save()
+			msg = _("Settings saved successfully !")
+			self.session.open(
+				MessageBox,
+				msg,
+				type=MessageBox.TYPE_INFO,
+				timeout=6,
+			)
+
 		self.close(True)
 
 	def keyLeft(self):
@@ -432,7 +455,7 @@ class EPGImportConfig(ConfigListScreen, Screen):
 				self.session.openWithCallback(self.textEditCallback, VirtualKeyBoard, text=self.EPG.shell_name.value)
 
 	def textEditCallback(self, callback=None):
-		if callback != None:
+		if callback is not None:
 			self.EPG.shell_name.value = callback
 			self.EPG.shell_name.save()
 			self.createSetup()
@@ -443,8 +466,8 @@ class EPGImportConfig(ConfigListScreen, Screen):
 		if isFilterRunning == 1:
 			text = self.filterStatusTemplate % (str(filterCounter))
 		elif epgimport.isImportRunning():
-				src = epgimport.source
-				text = self.importStatusTemplate % (src.description, epgimport.eventCount)
+			src = epgimport.source
+			text = self.importStatusTemplate % (src.description, epgimport.eventCount)
 
 		self["status"].setText(text)
 		if lastImportResult and (lastImportResult != self.lastImportResult):
@@ -621,10 +644,10 @@ class EPGImportProfile(ConfigListScreen, Screen):
 	def __init__(self, session):
 		Screen.__init__(self, session)
 		self.setTitle(_("Days Profile"))
-		self.list = []
+		settingsList = []
 		for i in range(7):
-			self.list.append(getConfigListEntry(weekdays[i], config.plugins.extra_epgimport.day_import[i]))
-		ConfigListScreen.__init__(self, self.list)
+			settingsList.append(getConfigListEntry(weekdays[i], config.plugins.extra_epgimport.day_import[i]))
+		ConfigListScreen.__init__(self, settingsList)
 		self["key_red"] = Button(_("Cancel"))
 		self["key_green"] = Button(_("Save"))
 		self["setupActions"] = ActionMap(["SetupActions", "ColorActions"],
@@ -637,15 +660,14 @@ class EPGImportProfile(ConfigListScreen, Screen):
 		}, -2)
 
 	def save(self):
-		if not config.plugins.extra_epgimport.day_import[0].value:
-			if not config.plugins.extra_epgimport.day_import[1].value:
-				if not config.plugins.extra_epgimport.day_import[2].value:
-					if not config.plugins.extra_epgimport.day_import[3].value:
-						if not config.plugins.extra_epgimport.day_import[4].value:
-							if not config.plugins.extra_epgimport.day_import[5].value:
-								if not config.plugins.extra_epgimport.day_import[6].value:
-									self.session.open(MessageBox, _("You may not use this settings!\nAt least one day a week should be included!"), MessageBox.TYPE_INFO, timeout=6)
-									return
+		if all(not config.plugins.extra_epgimport.day_import[i].value for i in range(7)):
+			self.session.open(
+				MessageBox,
+				_("You may not use this settings!\nAt least one day a week should be included!"),
+				MessageBox.TYPE_INFO,
+				timeout=6
+			)
+			return
 		ConfigListScreen.keySave(self)
 
 
@@ -695,10 +717,15 @@ class EPGImportLog(Screen):
 
 	def save(self):
 		try:
-			f = open('/tmp/epgimport.log', 'w')
-			f.write(log.getvalue())
-			self.session.open(MessageBox, _("Write to /tmp/epgimport.log"), MessageBox.TYPE_INFO, timeout=5, close_on_any_key=True)
-			f.close()
+			with open("/tmp/epgimport.log", "w") as f:
+				f.write(self.log.getvalue())
+			msg = _("Write to /tmp/epgimport.log")
+			self.session.open(
+				MessageBox,
+				msg,
+				MessageBox.TYPE_INFO,
+				timeout=10
+			)
 		except Exception as e:
 			self["list"].setText("Failed to write /tmp/epgimport.log:str" + str(e))
 		self.close(True)
@@ -714,7 +741,14 @@ class EPGImportLog(Screen):
 
 class EPGImportDownloader(MessageBox):
 	def __init__(self, session):
-		MessageBox.__init__(self, session, _("Last import: ") + config.plugins.extra_epgimport.last_import.value + _(" events\n") + _("\nImport of epg data will start.\nThis may take a few minutes.\nIs this ok?"), MessageBox.TYPE_YESNO)
+		MessageBox.__init__(
+			self,
+			session,
+			_("Last import: ") + config.plugins.extra_epgimport.last_import.value + _(" events\n") +
+			_("\nImport of epg data will start.\nThis may take a few minutes.\nIs this ok?"),
+			MessageBox.TYPE_YESNO,
+			timeout=15
+		)
 		self.skinName = "MessageBox"
 
 
@@ -737,7 +771,7 @@ def main(session, **kwargs):
 def doneConfiguring(retval=False):
 	if retval is True:
 		if autoStartTimer is not None:
-			autoStartTimer.update()
+			autoStartTimer.update(clock=True)
 
 
 def doneImport(reboot=False, epgfile=None):
@@ -747,7 +781,7 @@ def doneImport(reboot=False, epgfile=None):
 	lastImportResult = (time.time(), epgimport.eventCount)
 	try:
 		start, count = lastImportResult
-		#localtime = time.asctime(time.localtime(time.time()))
+		# localtime = time.asctime(time.localtime(time.time()))
 		localtime = time.strftime('%d.%m.%Y - %H:%M:%S', (time.localtime(time.time())))
 		lastimport = "%s, %d" % (localtime, count)
 		config.plugins.extra_epgimport.last_import.value = lastimport
@@ -784,13 +818,14 @@ def doneImport(reboot=False, epgfile=None):
 class checkDeepstandby:
 	def __init__(self, session, parse=False):
 		self.session = session
-		if parse:
-			self.FirstwaitCheck = enigma.eTimer()
-			self.FirstwaitCheck.callback.append(self.runCheckDeepstandby)
-			self.FirstwaitCheck.startLongTimer(600)
-			print("[EPGImport] Wait for parse autotimers 600 sec.", file=log)
-		else:
-			self.runCheckDeepstandby()
+		if config.plugins.epgimport.enabled.value:
+			if parse:
+				self.FirstwaitCheck = eTimer()
+				self.FirstwaitCheck.callback.append(self.runCheckDeepstandby)
+				self.FirstwaitCheck.startLongTimer(600)
+				print("[EPGImport] Wait for parse autotimers 600 sec.", file=log)
+			else:
+				self.runCheckDeepstandby()
 
 	def runCheckDeepstandby(self):
 		print("[EPGImport] Run check deep standby after import")
@@ -810,12 +845,12 @@ def restartEnigma(confirmed):
 		# save state of enigma, so we can return to previeus state
 	if Screens.Standby.inStandby:
 		try:
-			open('/tmp/enigmastandby', 'wb').close()
+			open(STANDBY_FLAG_FILE, 'wb').close()
 		except:
 			print("Failed to create /tmp/enigmastandby", file=log)
 	else:
 		try:
-			os.remove("/tmp/enigmastandby")
+			remove(STANDBY_FLAG_FILE)
 		except:
 			pass
 	# now reboot
@@ -830,9 +865,12 @@ class AutoStartTimer:
 		self.session = session
 		self.prev_onlybouquet = config.plugins.epgimport.import_onlybouquet.value
 		self.prev_multibouquet = config.usage.multibouquet.value
-		self.timer = enigma.eTimer()
-		self.timer.callback.append(self.onTimer)
-		self.pauseAfterFinishImportCheck = enigma.eTimer()
+		self.clock = config.plugins.epgimport.wakeup.value
+		self.autoStartImport = eTimer()
+		self.autoStartImport.callback.append(self.onTimer)
+		self.onceRepeatImport = eTimer()
+		self.onceRepeatImport.callback.append(self.runImport)
+		self.pauseAfterFinishImportCheck = eTimer()
 		self.pauseAfterFinishImportCheck.callback.append(self.afterFinishImportCheck)
 		self.pauseAfterFinishImportCheck.startLongTimer(30)
 		self.container = None
@@ -841,15 +879,17 @@ class AutoStartTimer:
 
 	def getWakeTime(self):
 		if config.plugins.epgimport.enabled.value:
-			clock = config.plugins.epgimport.wakeup.value
 			nowt = time.time()
 			now = time.localtime(nowt)
-			return int(time.mktime((now.tm_year, now.tm_mon, now.tm_mday, clock[0], clock[1], lastMACbyte() // 5, 0, now.tm_yday, now.tm_isdst)))
+			return int(time.mktime((now.tm_year, now.tm_mon, now.tm_mday, self.clock[0], self.clock[1], lastMACbyte() // 5, 0, now.tm_yday, now.tm_isdst)))
 		else:
 			return -1
 
-	def update(self, atLeast=0):
-		self.timer.stop()
+	def update(self, atLeast=0, clock=False):
+		self.autoStartImport.stop()
+		if clock and self.clock != config.plugins.epgimport.wakeup.value:
+			self.clock = config.plugins.epgimport.wakeup.value
+			self.onceRepeatImport.stop()
 		wake = self.getWakeTime()
 		now_t = time.time()
 		now = int(now_t)
@@ -866,8 +906,9 @@ class AutoStartTimer:
 				if not config.plugins.extra_epgimport.day_import[cur_day].value:
 					wake += 86400 * wakeup_day
 			next = wake - now
-			self.timer.startLongTimer(next)
+			self.autoStartImport.startLongTimer(next)
 		else:
+			self.onceRepeatImport.stop()
 			wake = -1
 		print("[EPGImport] WakeUpTime now set to", wake, "(now=%s)" % now, file=log)
 		return wake
@@ -885,7 +926,7 @@ class AutoStartTimer:
 			if config.plugins.epgimport.execute_shell.value and config.plugins.epgimport.shell_name.value:
 				if self.container:
 					del self.container
-				self.container = enigma.eConsoleAppContainer()
+				self.container = eConsoleAppContainer()
 				self.container.appClosed.append(self.executeShellEnd)
 				if self.container.execute(config.plugins.epgimport.shell_name.value):
 					self.executeShellEnd(-1)
@@ -899,7 +940,7 @@ class AutoStartTimer:
 		startImport()
 
 	def onTimer(self):
-		self.timer.stop()
+		self.autoStartImport.stop()
 		now = int(time.time())
 		print("[EPGImport] onTimer occured at", now, file=log)
 		wake = self.getWakeTime()
@@ -907,6 +948,10 @@ class AutoStartTimer:
 		atLeast = 0
 		if wake - now < 60:
 			self.runImport()
+			repeat_time = config.plugins.epgimport.repeat_import.value
+			if repeat_time:
+				self.onceRepeatImport.startLongTimer(repeat_time * 3600)
+				print("[EPGImport] start once repeat timer, wait in nours -", repeat_time, file=log)
 			atLeast = 60
 		self.update(atLeast)
 
@@ -939,7 +984,7 @@ class AutoStartTimer:
 
 	def afterFinishImportCheck(self):
 		if config.plugins.epgimport.deepstandby.value == 'wakeup' and getFPWasTimerWakeup():
-			if os.path.exists("/tmp/enigmastandby") or os.path.exists("/tmp/.EPGImportAnswerBoot"):
+			if exists(STANDBY_FLAG_FILE) or exists("/tmp/.EPGImportAnswerBoot"):
 				print("[EPGImport] is restart enigma2", file=log)
 			else:
 				wake = self.getStatus()
@@ -957,7 +1002,7 @@ class AutoStartTimer:
 								print("[EPGImport] Run to standby after wake up for checking", file=log)
 						if not config.plugins.epgimport.deepstandby_afterimport.value:
 							config.plugins.epgimport.deepstandby_afterimport.value = True
-							self.wait_timer = enigma.eTimer()
+							self.wait_timer = eTimer()
 							self.wait_timer.timeout.get().append(self.startStandby)
 							print("[EPGImport] start wait_timer (10sec) for goto standby", file=log)
 							self.wait_timer.start(10000, True)
@@ -999,7 +1044,7 @@ def WakeupDayOfWeek():
 	except:
 		cur_day = -1
 	if cur_day >= 0:
-		for i in (1, 2, 3, 4, 5, 6, 7):
+		for i in range(1, 8):
 			if config.plugins.extra_epgimport.day_import[(cur_day + i) % 7].value:
 				return i
 	return start_day
@@ -1025,7 +1070,7 @@ def onBootStartCheck():
 			print("[EPGImport] is automatic boot", file=log)
 		flag = '/tmp/.EPGImportAnswerBoot'
 		if config.plugins.epgimport.runboot_restart.value:
-			if os.path.exists(flag):
+			if exists(flag):
 				on_start = False
 				print("[EPGImport] not starting import - is restart enigma2", file=log)
 			else:
@@ -1059,12 +1104,12 @@ def autostart(reason, session=None, **kwargs):
 			if config.plugins.epgimport.runboot.value != "4":
 				onBootStartCheck()
 		# If WE caused the reboot, put the box back in standby.
-		if os.path.exists("/tmp/enigmastandby"):
+		if exists(STANDBY_FLAG_FILE):
 			print("[EPGImport] Returning to standby", file=log)
 			if not Screens.Standby.inStandby:
 				Notifications.AddNotification(Screens.Standby.Standby)
 			try:
-				os.remove("/tmp/enigmastandby")
+				remove(STANDBY_FLAG_FILE)
 			except:
 				pass
 
@@ -1072,7 +1117,7 @@ def autostart(reason, session=None, **kwargs):
 def getNextWakeup():
 	"returns timestamp of next time when autostart should be called"
 	if autoStartTimer:
-		if config.plugins.epgimport.deepstandby.value == 'wakeup' and autoStartTimer.getSources():
+		if config.plugins.epgimport.enabled.value and config.plugins.epgimport.deepstandby.value == 'wakeup' and autoStartTimer.getSources():
 			print("[EPGImport] Will wake up from deep sleep", file=log)
 			return autoStartTimer.getStatus()
 	return -1
