@@ -81,6 +81,9 @@ class hotkey:
 		("Skip back", "skip_back", ""),
 		("Skip forward", "skip_forward", ""),
 		("Activate PiP", "activatePiP", ""),
+		("Activate PiP" + " " + _("long"), "activatePiP_long", ""),
+		("History", "history", ""),
+		("History" + " " + _("long"), "history_long", ""),
 		("Timer", "timer", ""),
 		("Timer" + " " + _("long"), "timer_long", ""),
 		("Playlist", "playlist", ""),
@@ -670,7 +673,7 @@ class InfoBarHotkey:
 					return 0
 			elif selected[0] == "Module":
 				try:
-					exec("from %s import %s" % (selected[1], selected[2]))
+					exec("from %s import %s" % (selected[1], selected[2]), globals())
 					exec("self.session.open(%s)" % ",".join(selected[2:]))
 				except Exception as e:
 					print("[Hotkey] error during executing module %s, screen %s, %s" % (selected[1], selected[2], e))
@@ -716,10 +719,10 @@ class InfoBarHotkey:
 				if os.path.isfile(command):
 					if ".hidden." in command:
 						from enigma import eConsoleAppContainer
-						eConsoleAppContainer().execute("python %s" % command)
+						eConsoleAppContainer().execute("python3 %s" % command)
 					else:
 						from Screens.Console import Console
-						self.session.open(Console, selected[1] + " pythonscript", "python %s" % command, closeOnSuccess=selected[1].startswith('!'), showStartStopText=False)
+						self.session.open(Console, selected[1] + " pythonscript", "python3 %s" % command, closeOnSuccess=selected[1].startswith('!'), showStartStopText=False)
 			elif selected[0] == "Menu":
 				from Screens.Menu import MainMenu, mdom
 				root = mdom.getroot()
