@@ -269,7 +269,7 @@ class PluginDownloadBrowser(Screen):
 		self.container.appClosed.append(self.runFinished)
 		self.container.dataAvail.append(self.dataAvail)
 		self.onLayoutFinish.append(self.startRun)
-		self.setTitle(self.type == self.DOWNLOAD and _("Downloadable new plugins") or _("Remove plugins"))
+		self.setTitle(_("Downloadable new plugins") if self.type == self.DOWNLOAD else _("Remove plugins"))
 		self.list = []
 		self["list"] = PluginList(self.list)
 		self.pluginlist = []
@@ -282,7 +282,9 @@ class PluginDownloadBrowser(Screen):
 		self.install_settings_name = ''
 		self.remove_settings_name = ''
 		self["text"] = Label(_("Downloading plugin information. Please wait...") if self.type == self.DOWNLOAD else _("Getting plugin information. Please wait..."))
-		self["key_red" if self.type == self.DOWNLOAD else "key_green"] = Label(_("Remove plugins") if self.type == self.DOWNLOAD else _("Download plugins"))
+		self["key_red"] = Label(_("Cancel"))
+		self["key_green"] = Label(_("Expand"))
+		self["key_blue"] = Label(_("Remove plugins") if self.type == self.DOWNLOAD else _("Download plugins"))
 		self.run = 0
 		self.remainingdata = ""
 		self["actions"] = ActionMap(["WizardActions"],
@@ -290,7 +292,11 @@ class PluginDownloadBrowser(Screen):
 			"ok": self.go,
 			"back": self.requestClose,
 		})
-		self["PluginDownloadActions"] = ActionMap(["ColorActions"],	{"red": self.delete} if self.type == self.DOWNLOAD else {"green": self.download})
+		self["PluginDownloadActions"] = ActionMap(["ColorActions"], {
+			"blue": self.delete if self.type == self.DOWNLOAD else self.download,
+			"red": self.requestClose,
+			"green": self.go}
+		)
 		if os.path.isfile('/usr/bin/opkg'):
 			self.opkg = '/usr/bin/opkg'
 			self.opkg_install = self.opkg + ' install'
@@ -299,25 +305,32 @@ class PluginDownloadBrowser(Screen):
 			self.opkg = 'opkg'
 			self.opkg_install = 'opkg install -force-defaults'
 			self.opkg_remove = self.opkg + ' remove'
+		self["list"].onSelectionChanged.append(self.selectionChanged)
+
+	def selectionChanged(self):
+		selection = self["list"].l.getCurrentSelection()
+		if selection:
+			selection = selection[0]
+			if isinstance(selection, str): # category
+				self["key_green"].text = _("Collapse") if selection in self.expanded else _("Expand")
+			else:
+				self["key_green"].text = _("Install plugin") if self.type == self.DOWNLOAD else _("Remove plugin")
 
 	def go(self):
-		sel = self["list"].l.getCurrentSelection()
-
-		if sel is None:
-			return
-
-		sel = sel[0]
-		if isinstance(sel, str): # category
-			if sel in self.expanded:
-				self.expanded.remove(sel)
+		selection = self["list"].l.getCurrentSelection()
+		if selection:
+			selection = selection[0]
+			if isinstance(selection, str): # category
+				if selection in self.expanded:
+					self.expanded.remove(selection)
+				else:
+					self.expanded.append(selection)
+				self.updateList()
 			else:
-				self.expanded.append(sel)
-			self.updateList()
-		else:
-			if self.type == self.DOWNLOAD:
-				self.session.openWithCallback(self.runInstall, MessageBox, _("Do you really want to download\nthe plugin \"%s\"?") % sel.name)
-			elif self.type == self.REMOVE:
-				self.session.openWithCallback(self.runInstall, MessageBox, _("Do you really want to remove\nthe plugin \"%s\"?") % sel.name)
+				if self.type == self.DOWNLOAD:
+					self.session.openWithCallback(self.runInstall, MessageBox, _("Do you really want to download\nthe plugin \"%s\"?") % selection.name)
+				elif self.type == self.REMOVE:
+					self.session.openWithCallback(self.runInstall, MessageBox, _("Do you really want to remove\nthe plugin \"%s\"?") % selection.name)
 
 	def delete(self):
 		self.requestClose(1)
