@@ -15,7 +15,7 @@ import zlib
 from dataclasses import dataclass
 from functools import wraps
 from http.cookiejar import CookieJar
-from typing import TYPE_CHECKING, Iterable, Optional
+from typing import TYPE_CHECKING, Hashable, Iterable, Optional
 from urllib.parse import urldefrag, urljoin, urlunparse as _urlunparse
 
 from zope.interface import implementer
@@ -26,7 +26,13 @@ from twisted.internet import defer, protocol, task
 from twisted.internet.abstract import isIPv6Address
 from twisted.internet.defer import Deferred
 from twisted.internet.endpoints import HostnameEndpoint, wrapClientTLS
-from twisted.internet.interfaces import IOpenSSLContextFactory, IProtocol
+from twisted.internet.interfaces import (
+    IAddress,
+    IOpenSSLContextFactory,
+    IProtocol,
+    IReactorTime,
+    IStreamClientEndpoint,
+)
 from twisted.logger import Logger
 from twisted.python.compat import nativeString, networkString
 from twisted.python.components import proxyForInterface
@@ -39,7 +45,7 @@ from twisted.python.failure import Failure
 from twisted.python.util import InsensitiveDict
 from twisted.web import error, http
 from twisted.web._newclient import _ensureValidMethod, _ensureValidURI
-from twisted.web.http_headers import Headers
+from twisted.web.http_headers import Headers, _nameEncoder
 from twisted.web.iweb import (
     UNKNOWN_LENGTH,
     IAgent,
@@ -685,7 +691,7 @@ class URI:
         scheme, netloc, path, params, query, fragment = http.urlparse(uri)
 
         if defaultPort is None:
-            if scheme == b"https":
+            if scheme in {b"https", b"wss"}:
                 defaultPort = 443
             else:
                 defaultPort = 80
@@ -1265,7 +1271,7 @@ class _HTTP11ClientFactory(protocol.Factory):
             self._quiescentCallback, self._metadata
         )
 
-    def buildProtocol(self, addr):
+    def buildProtocol(self, addr: IAddress) -> HTTP11ClientProtocol:
         return HTTP11ClientProtocol(self._quiescentCallback)
 
 
@@ -1384,7 +1390,9 @@ class HTTPConnectionPool:
         self._connections = {}
         self._timeouts = {}
 
-    def getConnection(self, key, endpoint):
+    def getConnection(
+        self, key: Hashable, endpoint: IStreamClientEndpoint
+    ) -> Deferred[HTTP11ClientProtocol]:
         """
         Supply a connection, newly created or retrieved from the pool, to be
         used for one HTTP request.
@@ -1422,7 +1430,9 @@ class HTTPConnectionPool:
 
         return self._newConnection(key, endpoint)
 
-    def _newConnection(self, key, endpoint):
+    def _newConnection(
+        self, key: Hashable, endpoint: IStreamClientEndpoint
+    ) -> Deferred[HTTP11ClientProtocol]:
         """
         Create a new connection.
 
@@ -1433,7 +1443,10 @@ class HTTPConnectionPool:
             self._putConnection(key, protocol)
 
         factory = self._factory(quiescentCallback, repr(endpoint))
-        return endpoint.connect(factory)
+        result: Deferred[HTTP11ClientProtocol] = endpoint.connect(
+            factory
+        )  # type:ignore[assignment]
+        return result
 
     def _removeConnection(self, key, connection):
         """
@@ -1499,7 +1512,7 @@ class _AgentBase:
     @ivar _pool: The L{HTTPConnectionPool} used to manage HTTP connections.
     """
 
-    def __init__(self, reactor, pool):
+    def __init__(self, reactor: IReactorTime, pool: HTTPConnectionPool | None) -> None:
         if pool is None:
             pool = HTTPConnectionPool(reactor, False)
         self._reactor = reactor
@@ -1517,8 +1530,15 @@ class _AgentBase:
         return b"%b:%d" % (host, port)
 
     def _requestWithEndpoint(
-        self, key, endpoint, method, parsedURI, headers, bodyProducer, requestPath
-    ):
+        self,
+        key: tuple[bytes, bytes, int],
+        endpoint: IStreamClientEndpoint,
+        method: bytes,
+        parsedURI: URI,
+        headers: Headers | None,
+        bodyProducer: IBodyProducer | None,
+        requestPath: bytes,
+    ) -> Deferred[IResponse]:
         """
         Issue a new request, given the endpoint and the path sent as part of
         the request.
@@ -1531,10 +1551,10 @@ class _AgentBase:
         # Create minimal headers, if necessary:
         if headers is None:
             headers = Headers()
-        if not headers.hasHeader(b"host"):
+        if not headers.hasHeader(b"Host"):
             headers = headers.copy()
             headers.addRawHeader(
-                b"host",
+                b"Host",
                 self._computeHostValue(
                     parsedURI.scheme, parsedURI.host, parsedURI.port
                 ),
@@ -1542,7 +1562,7 @@ class _AgentBase:
 
         d = self._pool.getConnection(key, endpoint)
 
-        def cbConnected(proto):
+        def cbConnected(proto: HTTP11ClientProtocol) -> Deferred[IResponse]:
             return proto.request(
                 Request._construct(
                     method,
@@ -1554,8 +1574,7 @@ class _AgentBase:
                 )
             )
 
-        d.addCallback(cbConnected)
-        return d
+        return d.addCallback(cbConnected)
 
 
 @implementer(IAgentEndpointFactory)
@@ -1595,7 +1614,7 @@ class _StandardEndpointFactory:
         self._connectTimeout = connectTimeout
         self._bindAddress = bindAddress
 
-    def endpointForURI(self, uri):
+    def endpointForURI(self, uri: URI) -> IStreamClientEndpoint:
         """
         Connect directly over TCP for C{b'http'} scheme, and TLS for
         C{b'https'}.
@@ -1603,7 +1622,6 @@ class _StandardEndpointFactory:
         @param uri: L{URI} to connect to.
 
         @return: Endpoint to connect to.
-        @rtype: L{IStreamClientEndpoint}
         """
         kwargs = {}
         if self._connectTimeout is not None:
@@ -1622,9 +1640,9 @@ class _StandardEndpointFactory:
             )
 
         endpoint = HostnameEndpoint(self._reactor, host, uri.port, **kwargs)
-        if uri.scheme == b"http":
+        if uri.scheme in {b"http", b"ws"}:
             return endpoint
-        elif uri.scheme == b"https":
+        elif uri.scheme in {b"https", b"wss"}:
             connectionCreator = self._policyForHTTPS.creatorForNetloc(
                 uri.host, uri.port
             )
@@ -1756,7 +1774,13 @@ class Agent(_AgentBase):
         """
         return self._endpointFactory.endpointForURI(uri)
 
-    def request(self, method, uri, headers=None, bodyProducer=None):
+    def request(
+        self,
+        method: bytes,
+        uri: bytes,
+        headers: Optional[Headers] = None,
+        bodyProducer: Optional[IBodyProducer] = None,
+    ) -> Deferred[IResponse]:
         """
         Issue a request to the server indicated by the given C{uri}.
 
@@ -1974,12 +1998,12 @@ class CookieAgent:
         lastRequest = _FakeStdlibRequest(uri)
         # Setting a cookie header explicitly will disable automatic request
         # cookies.
-        if not actualHeaders.hasHeader(b"cookie"):
+        if not actualHeaders.hasHeader(b"Cookie"):
             self.cookieJar.add_cookie_header(lastRequest)
             cookieHeader = lastRequest.get_header("Cookie", None)
             if cookieHeader is not None:
                 actualHeaders = actualHeaders.copy()
-                actualHeaders.addRawHeader(b"cookie", networkString(cookieHeader))
+                actualHeaders.addRawHeader(b"Cookie", networkString(cookieHeader))
 
         return self._agent.request(
             method, uri, actualHeaders, bodyProducer
@@ -2109,7 +2133,7 @@ class ContentDecoderAgent:
             headers = Headers()
         else:
             headers = headers.copy()
-        headers.addRawHeader(b"accept-encoding", self._supported)
+        headers.addRawHeader(b"Accept-Encoding", self._supported)
         deferred = self._agent.request(method, uri, headers, bodyProducer)
         return deferred.addCallback(self._handleResponse)
 
@@ -2117,7 +2141,7 @@ class ContentDecoderAgent:
         """
         Check if the response is encoded, and wrap it to handle decompression.
         """
-        contentEncodingHeaders = response.headers.getRawHeaders(b"content-encoding", [])
+        contentEncodingHeaders = response.headers.getRawHeaders(b"Content-Encoding", [])
         contentEncodingHeaders = b",".join(contentEncodingHeaders).split(b",")
         while contentEncodingHeaders:
             name = contentEncodingHeaders.pop().strip()
@@ -2130,14 +2154,14 @@ class ContentDecoderAgent:
                 break
         if contentEncodingHeaders:
             response.headers.setRawHeaders(
-                b"content-encoding", [b",".join(contentEncodingHeaders)]
+                b"Content-Encoding", [b",".join(contentEncodingHeaders)]
             )
         else:
-            response.headers.removeHeader(b"content-encoding")
+            response.headers.removeHeader(b"Content-Encoding")
         return response
 
 
-_canonicalHeaderName = Headers()._encodeName
+_canonicalHeaderName = _nameEncoder.encode
 _defaultSensitiveHeaders = frozenset(
     [
         b"Authorization",
